@@ -1,5 +1,5 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
-;;  Copyright (C) 2013,2014,2015,2016,2017,2018,2019
+;;  Copyright (C) 2013,2014,2015,2016,2017,2018,2019,2020,2021
 ;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
@@ -34,6 +34,7 @@
   #:use-module (artanis third-party csv)
   #:use-module (artanis third-party json)
   #:use-module (artanis server)
+  #:use-module (artanis cache)
   #:use-module (artanis websocket)
   #:use-module (artanis lpc)
   #:use-module (artanis version)
@@ -55,6 +56,7 @@
                run-when-sigint!
                emit-response-with-file
                static-page-emitter
+               current-myhost
 
                ;; oht module
                get
@@ -74,6 +76,8 @@
                :cookies-update!
                :cookies-remove!
                :cookies-setattr!
+               :cookies-check
+               :cookies-value
                :mime
                :auth
                :session
@@ -170,6 +174,11 @@
                store-uploaded-files
                upload-files-to
 
+               ;; cache
+               try-to-get-page-from-cache
+               cache-this-page
+               clear-content-cache
+
                ;; websocket
                named-pipe-subscribe
 
@@ -214,7 +223,7 @@
   (sigaction SIGINT (lambda (i)
                       (run-when-sigint-hook)
                       (format (artanis-current-output)
-                              "~%Fare you well, you server is cold.~%")
+                              "~%Fare you well, your server is cold.~%")
                       (quit)))
   (set! is-init-server-run? #t))
 
