@@ -1,5 +1,5 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
-;;  Copyright (C) 2013,2014,2015,2016,2017,2018,2019
+;;  Copyright (C) 2013,2014,2015,2016,2017,2018,2019,2021
 ;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
@@ -252,6 +252,11 @@ server.mmapped = <boolean>")
      "The allowed HTTP methods.
 server.allowedmethods = <methods-list>")
 
+    ((server jsmanifest)
+     "pub"
+     "The path to find \"manifest.json\".
+server.jsmanifest = <string>")
+
     ((websocket maxpayload)
      ,(1- (ash 1 64))
      "The maximum payload size of WebSocket request in bytes. If it exceeds, then it
@@ -285,8 +290,8 @@ websocket.timeout = <integer>")
     ((host name)
      #f
      "If disabled, you will have to use the IP address to connect instead of the
-hostname. e.g. `host.addr = 127.0.0.1'.
-host.name = enable | disable | <boolean>")
+hostname. e.g. `host.name = lambdachip.com'.
+host.name = <string> | disable")
 
     ((host addr)
      "127.0.0.1"
@@ -358,7 +363,14 @@ debug.enable = <boolean>")
      "The paths that needs to be monitored in debug-mode.
 This will take advantage of `inotify' in GNU/Linux kernel.
 NOTE: We may support GNU/Hurd as well, with its file monitor mechanism, in the future.
-debug.monitor = <PATHs>")))
+debug.monitor = <PATHs>")
+ ((cookie expires)
+       3600
+      "Cookie expiration time in seconds.
+       1 hour is 3600
+       6 hours 21600
+       1 month 2592000
+ cookie.expires = <integer>")))
 
 ;; Init all fields with default values
 (for-each (lambda (x) (conf-set! (car x) (cadr x))) (default-conf-values))
@@ -469,6 +481,7 @@ debug.monitor = <PATHs>")))
     (('sendfile v) (conf-set! '(server sendfile) (->bool v)))
     (('mmapped v) (conf-set! '(server mmapped) (->bool v)))
     (('allowedmethods ml) (conf-set! '(server allowedmethods) (->methods ml)))
+    (('jsmanifest jm) (conf-set! '(server jsmanifest) (->none/str jm)))
     (else (error parse-namespace-server "Config: Invalid item" item))))
 
 (define (parse-namespace-websocket item)
@@ -522,13 +535,18 @@ debug.monitor = <PATHs>")))
 (define (parse-namespace-cache item)
   (match item
     (('maxage maxage) (conf-set! '(cache maxage) (->integer maxage)))
-    (else (error parse-namespace-mail "Config: Invalid item" item))))
+    (else (error parse-namespace-cache "Config: Invalid item" item))))
 
 (define (parse-namespace-debug item)
   (match item
     (('enable enable) (conf-set! 'debug-mode (->bool enable)))
     (('monitor monitor) (conf-set! '(debug monitor) (->list monitor)))
-    (else (error parse-namespace-cache "Config: Invalid item" item))))
+    (else (error parse-namespace-debug "Config: Invalid item" item))))
+
+(define (parse-namespace-cookie item)
+  (match item
+     (('expire expire) (conf-set! '(cookie expires) (->integer expire)))
+    (else (error parse-namespace-cookie "Config: Invalid item" item))))
 
 (define (parse-config-item item)
   (match item
@@ -541,6 +559,7 @@ debug.monitor = <PATHs>")))
     (('mail rest ...) (parse-namespace-mail rest))
     (('cache rest ...) (parse-namespace-cache rest))
     (('debug rest ...) (parse-namespace-debug rest))
+    (('cookie rest ...) (parse-namespace-cookie rest))
     (((? string-null?)) #t) ; skip
     (else (error parse-config-item "Unsupported config namespace!" item))))
 
@@ -627,14 +646,14 @@ debug.monitor = <PATHs>")))
          (port (get-conf '(host port))))
     (if for-header?
         (cons real-host #f)
-        (format #f "http://~a:~a" (get-conf '(host addr)) port))))
+        (format #f "http://~a:~a" real-host port))))
 
 (define (init-config)
   (define conf-file (current-conf-file)) ; user specified config
   (define fp (open-input-file
               (cond
                ((and conf-file (file-exists? conf-file))
-                (format (artanis-current-output) "Loading conf/artanis.conf...")
+                (format (artanis-current-output) "Loading ~a..." conf-file)
                 conf-file)
                ((file-exists? *default-conf-file*)
                 (format (artanis-current-output) "Loading ~a..." *default-conf-file*)
