@@ -49,7 +49,7 @@
     ((_ fmt args ...)
      (format #f fmt args ...))))
 
-;; NOTE: According to SQL standard, we should always use single-quote. 
+;; NOTE: According to SQL standard, we should always use single-quote.
 (define *double-quote-re* (string->irregex "\""))
 (define-syntax-rule (->end name arg)
   (irregex-replace/all *double-quote-re* (-> end "~a ~a" name arg) "'"))
@@ -67,13 +67,13 @@
      (-> "~a where ~a" sentence (sql-where rest ...)))))
 
 (define-syntax-rule (->lst pairs)
-  (map (lambda (l) (-> "~{~a~^=~s~}" l)) pairs))
+  (map (lambda (l) (-> "~{~a~^='~a'~}" l)) pairs))
 
 (define (->cond lst)
   (define (->logical and/or ll)
     (string-join (map ->cond ll) (format #f " ~a " and/or)))
   (define (->op2 op a1 a2) (-> "~a~a~s" a1 op a2))
-  (define (->opn opn . ll) (-> "~a ~{~s~^ ~}" opn ll))
+  (define (->opn opn . ll) (-> "~a ~{'~a'~^ ~}" opn ll))
   (match lst
     (() "")
     (('and ll ...) (->logical 'and ll))
@@ -98,9 +98,9 @@
     ((_ column in (select rest ...))
      (-> "~a in (~{~a~^,~}) in (select ~a)" 'column (sql-select rest ...)))
     ((_ column like pattern)
-     (-> "~a like ~s" 'column pattern))
+     (-> "~a like '~a'" 'column pattern))
     ((_ column between a and b)
-     (-> "~a between ~s and ~s" 'column a b))
+     (-> "~a between '~a' and '~a'" 'column a b))
     ((_ column is null)
      (-> "~a is null" 'column))
     ;; e.g.   (->sql select * from 'user where (and (= user "name") (> age 15)))
@@ -153,14 +153,14 @@
     ((_ into table select rest ...)
      (-> "into ~a select ~a" table (sql-select rest ...)))
     ((_ into table values lst)
-     (-> "into ~a values (~{~s~^,~})" table lst))
+     (-> "into ~a values (~{'~a'~^,~})" table lst))
     ((_ into table values lst select rest ...)
-     (-> "into ~a values (~{~s~^,~}) select ~a"
+     (-> "into ~a values (~{'~a'~^,~}) select ~a"
          table lst (sql-select rest ...)))
     ((_ into table fields values lst)
-     (-> "into ~a (~{~a~^,~}) values (~{~s~^,~})" table fields lst))
+     (-> "into ~a (~{~a~^,~}) values (~{'~a'~^,~})" table fields lst))
     ((_ into table fields values lst select rest ...)
-     (-> "into ~a (~{~a~^,~}) values (~{~s~^,~}) select ~a"
+     (-> "into ~a (~{~a~^,~}) values (~{'~a'~^,~}) select ~a"
          table fields lst (sql-select rest ...)))))
 
 (define-syntax sql-update
@@ -170,7 +170,7 @@
     ((_ table set pairs cond-str)
      (string-concatenate (list (sql-update table set pairs) cond-str)))
     ((_ table set pairs where rest ...)
-     (->where end (sql-update table set pairs) (sql-where rest ...)))))
+     (->where end (sql-update table set pairs) rest ...))))
 
 (define-syntax sql-delete
   (syntax-rules (* from where)
@@ -183,7 +183,7 @@
     ((_ from table cond-str)
      (-> "from ~a ~a" table cond-str))
     ((_ from table where rest ...)
-     (->where end (sql-delete from table) (sql-where rest ...)))))
+     (->where end (sql-delete from table) rest ...))))
 
 (define-syntax sql-create
   (syntax-rules (table view as select index unique on if exists not database)
@@ -335,6 +335,10 @@
       (else (throw 'artanis-err 500 gen-cond
                    (format #f "[SQL]~a: invalid range" (get-prefix))
                    lst))))
+  (define (->quote v)
+    (if (number? v)
+        v
+        (format #f "'~a'" v)))
   (define (get-the-conds-str key val)
     (let ((v (if (list? val) (->range val) val)))
       (match key
@@ -344,9 +348,9 @@
          ;; (artanis-check-if-current-DB-support key)
          (let ((k (symbol->string key)))
            (if (list? v)
-               (format #f " ~a ~{~s~^, ~} " k v)
-               (format #f " ~a ~s " k v))))
-        (else (format #f "~a~s" key v)))))
+               (format #f " ~a ~{~a~^, ~} " k (->quote v))
+               (format #f " ~a~a " k (->quote v)))))
+        (else (format #f "~a~a" key (->quote v))))))
   (match conds
     (() "")
     (((? string? c1) (? string? c2) . rest)
@@ -371,8 +375,8 @@
     ;; (where #:name '("John" "Tom" "Jim")) ==> name="John" or name="Tom" or name="Jim"
     (((? keyword? key) (vals ...) . rest)
      (let* ((kp (->key/pred key))
-            (fmt (string-concatenate `(,(get-prefix) "~{" ,kp "'~a'~^" ,(->or/and kp) "~}"))))
-       (format #f fmt vals)))
+            (fmt (string-concatenate `(,(get-prefix) "~{" ,kp "~a~^" ,(->or/and kp) "~}"))))
+       (format #f fmt (map ->quote vals))))
     (else (throw 'artanis-err 500 gen-cond
                  (format #f "[SQL]~a: invalid condition pattern" (get-prefix))
                  conds))))
@@ -399,5 +403,5 @@
   (match lst
     (() "")
     ((column (? list? vals))
-     (format #f " ~a in (~{~s~^,~}) " column vals))
+     (format #f " ~a in (~{'~a'~^,~}) " column vals))
     (else (throw 'artanis-err 500 /in "Invalid args" lst))))
