@@ -48,14 +48,14 @@
 ;; 4
 ;; simple cache test (for dynamic content)
 (get "/new" #:cache #t
-  (lambda (rc)
-    (:cache rc "hello world")))
+     (lambda (rc)
+       (:cache rc "hello world")))
 
 ;; 4.1
 ;; cache in auth should be private
 (get "/pauth" #:auth `(basic ,(lambda (rc u p) #t)) #:cache '(public "./test.scm")
-  (lambda (rc)
-    (:cache rc)))
+     (lambda (rc)
+       (:cache rc)))
 
 ;; test database (here we use mysql/mariaDB for an example)
 ;; there's a table for testing:
@@ -81,13 +81,13 @@
 (define (result->html r)
   (if r
       (call-with-output-string
-       (lambda (port)
-         (for-each (lambda (e) (format port "<p>~a: ~a</p>" (car e) (cdr e))) r)))
+        (lambda (port)
+          (for-each (lambda (e) (format port "<p>~a: ~a</p>" (car e) (cdr e))) r)))
       "no result"))
 
 ;; 5
 (get "/raw-sql"
-     #:raw-sql "select * from Persons where Lastname='lei'"
+  #:raw-sql "select * from Persons where Lastname='lei'"
   (lambda (rc)
     (let ((r (:raw-sql rc 'top)))
       (result->html r))))
@@ -95,7 +95,7 @@
 ;; 6
 ;; curl localhost:3000/conn/lei
 (get "/conn/:name"
-     #:conn #t
+  #:conn #t
   (lambda (rc)
     (let* ((name (params rc "name"))
            (r (:conn rc (->sql select * from 'Persons (where #:Lastname name)))))
@@ -104,7 +104,7 @@
 ;; 7
 ;; curl "localhost:3000/conn/lei;select * from Persons;"
 (get "/fucked/:name"
-     #:conn #t
+  #:conn #t
   (lambda (rc)
     (let* ((name (uri-decode (params rc "name")))
            (r (:conn rc (->sql select * from 'Persons (where #:Lastname name)))))
@@ -113,7 +113,7 @@
 ;; 8
 ;; curl localhost:3000/conn+str/lei
 (get "/conn[+]str/:name"
-     #:conn #t #:str "select * from Persons where Lastname=${:name}"
+  #:conn #t #:str "select * from Persons where Lastname=${:name}"
   (lambda (rc)
     (let ((r (:conn rc (:str rc))))
       (result->html (DB-get-top-row r)))))
@@ -121,69 +121,69 @@
 ;; 9
 ;; various format tests
 (get "/json" #:mime 'json
-  (lambda (rc)
-    (let ((j (json (object ("name" "nala") ("age" "15")))))
-      (:mime rc j))))
+     (lambda (rc)
+       (let ((j (scm->json-string '(("name" "nala") ("age" "15")))))
+         (:mime rc j))))
 
 ;; 9.1
 ;; JSONP test
 (get "/jsonp/:callback" #:mime 'jsonp
-  (lambda (rc)
-    (:mime rc (json (object ("name" "nala") ("age" "15"))) #:jsonp (params rc "callback"))))
+     (lambda (rc)
+       (:mime rc (scm->json-string '(("name" "nala") ("age" "15"))) #:jsonp (params rc "callback"))))
 
 ;; 10
 (get "/csv" #:mime 'csv
-  (lambda (rc)
-    (:mime rc '(("a" "1") ("b" "2")))))
+     (lambda (rc)
+       (:mime rc '(("a" "1") ("b" "2")))))
 
 ;; 11
 (get "/xml" #:mime 'xml
-  (lambda (rc)
-    (:mime rc '(*TOP* (WEIGHT (@ (unit "pound")) (NET (@ (certified "certified")) "67") (GROSS "95"))))))
+     (lambda (rc)
+       (:mime rc '(*TOP* (WEIGHT (@ (unit "pound")) (NET (@ (certified "certified")) "67") (GROSS "95"))))))
 
 ;; 12
 (get "/sxml" #:mime 'sxml
-  (lambda (rc)
-    (:mime rc '((a 1) (b 2)))))
+     (lambda (rc)
+       (:mime rc '((a 1) (b 2)))))
 
 ;; 13
 ;; cookies test
 (get "/cookie" #:cookies '(names cc)
-  (lambda (rc)
-    (:cookies-set! rc 'cc "sid" "123321")
-    (:cookies-ref rc 'cc "sid")))
+     (lambda (rc)
+       (:cookies-set! rc 'cc "sid" "123321")
+       (:cookies-ref rc 'cc "sid")))
 
 ;; 14
 (get "/cookie/:expires" #:cookies '(names cc)
-  (lambda (rc)
-    (:cookies-set! rc 'cc "sid" "123321")
-    (:cookies-setattr! rc 'cc #:expir (string->number (params rc "expires")))
-    "ok"))
+     (lambda (rc)
+       (:cookies-set! rc 'cc "sid" "123321")
+       (:cookies-setattr! rc 'cc #:expires (string->number (params rc "expires")))
+       "ok"))
 
 ;; 15
 ;; test for naive basic-auth
 (get "/bauth" #:auth `(basic ,(lambda (rc u p) (and (string=? u "mmr") (string=? p "123"))))
-  (lambda (rc) 
-    (if (:auth rc)
-        "auth ok"
-        (throw-auth-needed))))
+     (lambda (rc)
+       (if (:auth rc)
+           "auth ok"
+           (throw-auth-needed))))
 
 ;; 16
 ;; test for more complicated auth
 (post "/auth" #:auth '(table user "user" "passwd") #:session #t
-  (lambda (rc)
-    (cond
-     ((:session rc 'check) "auth ok (session)")
-     ((:auth rc) (:session rc 'spawn))
-     (else (redirect-to rc "/login?login_failed=true")))))
+      (lambda (rc)
+        (cond
+         ((:session rc 'check) "auth ok (session)")
+         ((:auth rc) (:session rc 'spawn))
+         (else (redirect-to rc "/login?login_failed=true")))))
 
 ;; 16.1
 ;; test for login successful
 (get "/enter" #:session #t
-  (lambda (rc)
-    (cond
-     ((:session rc 'check) "yes login!")
-     (else (redirect-to rc "/login?login_failed=true")))))
+     (lambda (rc)
+       (cond
+        ((:session rc 'check) "yes login!")
+        (else (redirect-to rc "/login?login_failed=true")))))
 
 ;; 17
 (get "/login"
@@ -197,11 +197,26 @@
 ;; to support dot as the delimiter of key-bindings in rule
 (get "/pkg/:name\\.:format"
   (lambda (rc)
-   (format #f "~a.~a" (params rc "name") (params rc "format"))))
+    (format #f "~a.~a" (params rc "name") (params rc "format"))))
 
 (get "/echo" #:websocket '(proto echo)
-  (lambda (rc)
-    (:websocket rc 'payload)))
+     (lambda (rc)
+       (:websocket rc 'payload)))
+
+(get "/robot" #:websocket '(proto echo) named-pipe-subscribe)
+
+(get "/welcome/:whom/:what" #:websocket 'send-only
+     (lambda (rc)
+       (:websocket rc 'send (params rc "whom") (params rc "what"))
+       "ok"))
+
+(get "/lpc/set/:what" #:lpc #t
+     (lambda (rc)
+       (:lpc rc 'set "test" (params rc "what"))))
+
+(get "/lpc/get/" #:lpc #t
+     (lambda (rc)
+       (:lpc rc 'get "test")))
 
 (run #:use-db? #t #:dbd 'mysql #:db-username "root" #:db-passwd "123" #:debug #t)
 
